@@ -11,7 +11,8 @@ def __init__ (value, parseMemory):
         parseMemory[5]=parseMemory[5].replace('|DATA-P|','')
     if '|DATA|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA|',f'{value}|DATA|')
-    elif ('|DATA1|' in parseMemory[5] and ' = ' in parseMemory[5]):
+    elif ('|DATA1|' in parseMemory[5]) and (parseMemory[6] == False):
+        #print(parseMemory)
         raise SyntaxError(f'invalid syntax (<file>, line {parseMemory[4]})\nVariable opened without assign')
     elif '|DATA1|' in parseMemory[5]:
         parseMemory[5]=parseMemory[5].replace('|DATA1|',f'{value}|DATA1|')
